@@ -146,12 +146,12 @@ void KFActionQueue::queue(KFAction *p)
 	else
 	{
 		kdDebug(KFAREA) << "Running action " << next->name() << endl;
-		TQObject::connect(next,TQT_SIGNAL(done(KFAction *,bool)),
-			this,TQT_SLOT(actionDone(KFAction *,bool)));
+		TQObject::connect(next,TQ_SIGNAL(done(KFAction *,bool)),
+			this,TQ_SLOT(actionDone(KFAction *,bool)));
 		// Propagate signals
-		TQObject::connect(next,TQT_SIGNAL(status(const TQString &,int)),
-			this,TQT_SIGNAL(status(const TQString &,int)));
-		TQTimer::singleShot(0,next,TQT_SLOT(exec()));
+		TQObject::connect(next,TQ_SIGNAL(status(const TQString &,int)),
+			this,TQ_SIGNAL(status(const TQString &,int)));
+		TQTimer::singleShot(0,next,TQ_SLOT(exec()));
 	}
 }
 
@@ -370,12 +370,12 @@ bool FloppyAction::startProcess()
 {
 	DEBUGSETUP;
 
-	connect(theProcess,TQT_SIGNAL(processExited(TDEProcess *)),
-		this,TQT_SLOT(processDone(TDEProcess *)));
-	connect(theProcess,TQT_SIGNAL(receivedStdout(TDEProcess *,char *,int)),
-		this,TQT_SLOT(processStdOut(TDEProcess *,char *,int)));
-	connect(theProcess,TQT_SIGNAL(receivedStderr(TDEProcess *,char *,int)),
-		this,TQT_SLOT(processStdErr(TDEProcess *,char *,int)));
+	connect(theProcess,TQ_SIGNAL(processExited(TDEProcess *)),
+		this,TQ_SLOT(processDone(TDEProcess *)));
+	connect(theProcess,TQ_SIGNAL(receivedStdout(TDEProcess *,char *,int)),
+		this,TQ_SLOT(processStdOut(TDEProcess *,char *,int)));
+	connect(theProcess,TQ_SIGNAL(receivedStderr(TDEProcess *,char *,int)),
+		this,TQ_SLOT(processStdErr(TDEProcess *,char *,int)));
 
         theProcess->setEnvironment( "LC_ALL", "C" ); // We need the untranslated output of the tool
 	return theProcess->start(TDEProcess::NotifyOnExit,
