@@ -126,33 +126,33 @@ void KgpgApp::readOptions(bool doresize)
 
 void KgpgApp::initActions()
 {
-        KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(slotFileNew()), actionCollection());
-        KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(slotFileOpen()), actionCollection());
-        KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(slotFileSaveAs()), actionCollection());
-        KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(slotFileQuit()), actionCollection());
-        KStdAction::cut(TQT_TQOBJECT(this), TQT_SLOT(slotEditCut()), actionCollection());
-        KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(slotEditCopy()), actionCollection());
-        KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(slotEditPaste()), actionCollection());
-	KStdAction::selectAll(TQT_TQOBJECT(this), TQT_SLOT(slotSelectAll()), actionCollection());
-	KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(slotOptions()), actionCollection(),"kgpg_config");
+        KStdAction::openNew(this, TQ_SLOT(slotFileNew()), actionCollection());
+        KStdAction::open(this, TQ_SLOT(slotFileOpen()), actionCollection());
+        KStdAction::saveAs(this, TQ_SLOT(slotFileSaveAs()), actionCollection());
+        KStdAction::quit(this, TQ_SLOT(slotFileQuit()), actionCollection());
+        KStdAction::cut(this, TQ_SLOT(slotEditCut()), actionCollection());
+        KStdAction::copy(this, TQ_SLOT(slotEditCopy()), actionCollection());
+        KStdAction::paste(this, TQ_SLOT(slotEditPaste()), actionCollection());
+	KStdAction::selectAll(this, TQ_SLOT(slotSelectAll()), actionCollection());
+	KStdAction::preferences(this, TQ_SLOT(slotOptions()), actionCollection(),"kgpg_config");
 
-        //KStdAction::keyBindings(guiFactory(), TQT_SLOT(configureShortcuts()), actionCollection());
-        //KStdAction::configureToolbars(TQT_TQOBJECT(this), TQT_SLOT(slotConfigureToolbars()), actionCollection());
+        //KStdAction::keyBindings(guiFactory(), TQ_SLOT(configureShortcuts()), actionCollection());
+        //KStdAction::configureToolbars(this, TQ_SLOT(slotConfigureToolbars()), actionCollection());
 
-        fileSave = KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(slotFileSave()), actionCollection());
-        (void) new TDEAction(i18n("&Encrypt File..."), "encrypted", 0,TQT_TQOBJECT(this), TQT_SLOT(slotFilePreEnc()), actionCollection(),"file_encrypt");
-        (void) new TDEAction(i18n("&Decrypt File..."), "decrypted", 0,TQT_TQOBJECT(this), TQT_SLOT(slotFilePreDec()), actionCollection(),"file_decrypt");
-	(void) new TDEAction(i18n("&Open Key Manager"), "kgpg", 0,TQT_TQOBJECT(this), TQT_SLOT(slotKeyManager()), actionCollection(),"key_manage");
-        editUndo = KStdAction::undo(TQT_TQOBJECT(this), TQT_SLOT(slotundo()), actionCollection());
-        editRedo = KStdAction::redo(TQT_TQOBJECT(this), TQT_SLOT(slotredo()), actionCollection());
-        //(void) new TDEAction(i18n("&Manage Keys"), "kgpg_manage", CTRL+Key_K,TQT_TQOBJECT(this), TQT_SLOT(slotManageKey()), actionCollection(),"keys_manage");
-        (void) new TDEAction(i18n("&Generate Signature..."),0, TQT_TQOBJECT(this), TQT_SLOT(slotPreSignFile()), actionCollection(), "sign_generate");
-        (void) new TDEAction(i18n("&Verify Signature..."),0, TQT_TQOBJECT(this), TQT_SLOT(slotPreVerifyFile()), actionCollection(), "sign_verify");
-        (void) new TDEAction(i18n("&Check MD5 Sum..."), 0,TQT_TQOBJECT(this), TQT_SLOT(slotCheckMd5()), actionCollection(), "sign_check");
-	KStdAction::print(TQT_TQOBJECT(this), TQT_SLOT(slotFilePrint()), actionCollection());
+        fileSave = KStdAction::save(this, TQ_SLOT(slotFileSave()), actionCollection());
+        (void) new TDEAction(i18n("&Encrypt File..."), "encrypted", 0,this, TQ_SLOT(slotFilePreEnc()), actionCollection(),"file_encrypt");
+        (void) new TDEAction(i18n("&Decrypt File..."), "decrypted", 0,this, TQ_SLOT(slotFilePreDec()), actionCollection(),"file_decrypt");
+	(void) new TDEAction(i18n("&Open Key Manager"), "kgpg", 0,this, TQ_SLOT(slotKeyManager()), actionCollection(),"key_manage");
+        editUndo = KStdAction::undo(this, TQ_SLOT(slotundo()), actionCollection());
+        editRedo = KStdAction::redo(this, TQ_SLOT(slotredo()), actionCollection());
+        //(void) new TDEAction(i18n("&Manage Keys"), "kgpg_manage", CTRL+Key_K,this, TQ_SLOT(slotManageKey()), actionCollection(),"keys_manage");
+        (void) new TDEAction(i18n("&Generate Signature..."),0, this, TQ_SLOT(slotPreSignFile()), actionCollection(), "sign_generate");
+        (void) new TDEAction(i18n("&Verify Signature..."),0, this, TQ_SLOT(slotPreVerifyFile()), actionCollection(), "sign_verify");
+        (void) new TDEAction(i18n("&Check MD5 Sum..."), 0,this, TQ_SLOT(slotCheckMd5()), actionCollection(), "sign_check");
+	KStdAction::print(this, TQ_SLOT(slotFilePrint()), actionCollection());
 
     // comment out for now, only confusing
-	//encodingAction=new TDEToggleAction(i18n("&Unicode (utf-8) Encoding"), 0, 0,this, TQT_SLOT(slotSetCharset()),actionCollection(),"charsets");
+	//encodingAction=new TDEToggleAction(i18n("&Unicode (utf-8) Encoding"), 0, 0,this, TQ_SLOT(slotSetCharset()),actionCollection(),"charsets");
 }
 
 void KgpgApp::slotSetFont(TQFont myFont)
@@ -181,7 +181,7 @@ void KgpgApp::initView()
 
         view = new KgpgView(this,0);
         //  doc->addView(view);
-	connect(view,TQT_SIGNAL(resetEncoding(bool)),this,TQT_SLOT(slotResetEncoding(bool)));
+	connect(view,TQ_SIGNAL(resetEncoding(bool)),this,TQ_SLOT(slotResetEncoding(bool)));
         setCentralWidget(view);
         setCaption(i18n("Untitled"),false); ///   doc->URL().fileName(),false);
 
@@ -276,7 +276,7 @@ void KgpgApp::slotFilePreDec()
                 }
                 KgpgLibrary *lib=new KgpgLibrary(this);
                 lib->slotFileDec(url,KURL(newname), customDecrypt);
-		connect(lib,TQT_SIGNAL(importOver(TQStringList)),this,TQT_SIGNAL(refreshImported(TQStringList)));
+		connect(lib,TQ_SIGNAL(importOver(TQStringList)),this,TQ_SIGNAL(refreshImported(TQStringList)));
         } else
                 openEncryptedDocumentFile(url);
 }
@@ -534,7 +534,7 @@ void KgpgApp::slotVerifyFile(KURL url)
                 ///////////////////////// pipe gpg command
                 KgpgInterface *verifyFileProcess=new KgpgInterface();
                 verifyFileProcess->KgpgVerifyFile(url,KURL(sigfile));
-                connect (verifyFileProcess,TQT_SIGNAL(verifyquerykey(TQString)),this,TQT_SLOT(importSignatureKey(TQString)));
+                connect (verifyFileProcess,TQ_SIGNAL(verifyquerykey(TQString)),this,TQ_SLOT(importSignatureKey(TQString)));
         }
 }
 
