@@ -37,7 +37,7 @@ class Monitor;
 
 class ProbeDialog : public KProgressDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ProbeDialog( const HostConfig &hostConfig, TQWidget *parent, const char *name = 0 );
